==> haskell-nonce-1.0.4-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-nonce.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: nonce
version: 1.0.4
id: nonce-1.0.4-FVKGUgg7dPV4209OR2WmDT
key: nonce-1.0.4-FVKGUgg7dPV4209OR2WmDT
license: BSD3
copyright: (c) 2014 Prowdsponsor
maintainer: Prowdsponsor <opensource@prowdsponsor.com>
homepage: https://github.com/prowdsponsor/nonce
synopsis: Generate cryptographic nonces.
description:
    According to the Wikipedia, a nonce is an arbitrary number used
    only once in a cryptographic communication.  This package
    contain helper functions for generating nonces.
    .
    There are many kinds of nonces used in different situations.
    It'\''s not guaranteed that by using the nonces from this package
    you won'\''t have any security issues.  Please make sure that the
    nonces generated via this package are usable on your design.
category: Cryptography
author: Felipe Lessa <felipe.lessa@prowdsponsor.com>
exposed: True
indefinite: False
exposed-modules:
    Crypto.Nonce
abi: a48ece171d69da6f8487824ada444f84
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/nonce-1.0.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/nonce-1.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/nonce-1.0.4
hs-libraries: HSnonce-1.0.4-FVKGUgg7dPV4209OR2WmDT
depends:
    base-4.10.1.0 base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be
    bytestring-0.10.8.2 text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
    transformers-0.5.2.0 entropy-0.3.8-459fr1KgYZzBPF08mWgtQU
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be=fce7541e6cf9cbf2867cdcb0a2552fb8
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=168216a11cdc39c8cc50d80b9c45a385
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             entropy-0.3.8-459fr1KgYZzBPF08mWgtQU=a6112742140c3bfa625711e5fba8dc1f
haddock-interfaces: /usr/share/doc/haskell-nonce/html/nonce.haddock
haddock-html: /usr/share/doc/haskell-nonce/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-nonce-1.0.5-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-nonce.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: nonce
version: 1.0.5
id: nonce-1.0.5-CQYBxLPeJWvXSwEJBqcuK
key: nonce-1.0.5-CQYBxLPeJWvXSwEJBqcuK
license: BSD3
copyright: (c) 2014 Prowdsponsor
maintainer: Prowdsponsor <opensource@prowdsponsor.com>
homepage: https://github.com/prowdsponsor/nonce
synopsis: Generate cryptographic nonces.
description:
    According to the Wikipedia, a nonce is an arbitrary number used
    only once in a cryptographic communication.  This package
    contain helper functions for generating nonces.
    .
    There are many kinds of nonces used in different situations.
    It'\''s not guaranteed that by using the nonces from this package
    you won'\''t have any security issues.  Please make sure that the
    nonces generated via this package are usable on your design.
category: Cryptography
author: Felipe Lessa <felipe.lessa@prowdsponsor.com>
exposed: True
indefinite: False
exposed-modules:
    Crypto.Nonce
abi: acaa18d57ebffa2df48621d18b4aa4b9
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/nonce-1.0.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/nonce-1.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/nonce-1.0.5
hs-libraries: HSnonce-1.0.5-CQYBxLPeJWvXSwEJBqcuK
depends:
    base-4.10.1.0 base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be
    bytestring-0.10.8.2 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    transformers-0.5.2.0 entropy-0.3.8-459fr1KgYZzBPF08mWgtQU
    unliftio-0.2.2.0-Bsw1MgzN0T4FJmUreg5aa2
    unliftio-core-0.1.0.0-9rQX9ZUGZDTAHFduIwCNuu
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be=fce7541e6cf9cbf2867cdcb0a2552fb8
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=0c99dc42f18da90e6080c205f57d188a
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             entropy-0.3.8-459fr1KgYZzBPF08mWgtQU=a6112742140c3bfa625711e5fba8dc1f
             unliftio-0.2.2.0-Bsw1MgzN0T4FJmUreg5aa2=1fa8e5a39d343aaf8d217db8e9cbdf60
             unliftio-core-0.1.0.0-9rQX9ZUGZDTAHFduIwCNuu=81694956f3a90ca47aa628d6ec33109b
haddock-interfaces: /usr/share/doc/haskell-nonce/html/nonce.haddock
haddock-html: /usr/share/doc/haskell-nonce/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
